==> lsof-4.98.0.tar.gz: lsof-4.98.0/docs/credits.md <==
## Credits

I owe an enormous debt to the users of lsof who have contributed
to its steady growth.  The size of the list of people who have
helped me, while it has grown too large to include in the lsof man
page any more, is a testimonial to their generosity.

First I acknowledge a debt to the work of Dan Bernstein, Michael
`Ford` Ditto, Tom Dunigan, Alexander Dupuy, Vik Lall, Ray Moody,
C. Spencer, Michael Spitzer and those who wrote Berkeley's fstat
program, all contributors to lsof's predecessors.

I thank Doug McKenzie for his HP-UX proctor program and Rich Kulawiec
for pointing it out.

Finally I thank all the following people who have used lsof, pointed
out its flaws, described its shortcomings, offered suggestions for
improving it, supplied code for it, gave me technical advice, and
provided test systems where I was able to do development work.

	Szilveszter Adam
	David Addison
	Elias Halldor Agustsson
	Per Allansson
	Jim Ankenbrandt
	Richard Allen
	Thomas Anders
	Ric Anderson
	Stuart Anderson
	Dimitry Andric
	Michael Antlitz
	Cato Auestad
	Marc Auslander
	Tigran Aivazian
	Jos Backus
	David Bacon
	Alexis Ballier
	Scott Ballew
	Ade Barkah
	Alon Bar-Lev
	Brett Bartick
	Anthony Baxter
	John Beacom
	Bruce Beare
	M. Jay Beck
	Marek Behun
	Bill Behr
	Michael Beirne
	Marc Bejarano
	Andrew Bell
	Steve Bellenot
	Robert Benites
	Dmitry Berezin
	Ulrich Bernhard
	Peter J. Bertoncini
	Dave Bianchi
	Mark Bixby
	Allan Black
	Jan Blunck
	Achim Bohnet
	Steve Bonds
	Mark Bonsack
	Volker Borchert
	Bill Bormann
	Ermin Borovac
	Heddy Boubaker
	Pieter Bowman
	Michael Bracewell
	H. Merijn Brand
	Danny Braniss
	Thomas Braunbeck
	Kieran Broadfoot
	Dean Brock
	Hal Brooks
	Andrew Brown
	Jim Brown
	Michael Bryan
	Matthew Burt
	Robert Byrnes
	Pierfrancesco Caci
	Bill Campbell
	David Capshaw
	John Caruso
	Jon Champlin
	Kris Chandrasekhar
	Stephane Chazelas
	Andrey Chernov
	Albert Chin-A-Young
	Bernt Christandl
	Marc Christensen
	Hans Petter Christiansen
	Tom Christiansen
	Yves Christophe
	Richard Chycoski
	A. Channing Clark
	Jorn Clausen
	Axel Clauberg
	John Clear
	David Clissold
	Richard Coley
	John Colgrave
	David Comay
	Lionel Cons
	Bob Cook
	Patrick Connor
	Carl Cook
	Jim Cooper
	Roger Cornelius
	Doug Crabill
	Eric Cronin
	Kim Culhan
	Dave Curry
	Robert Dahlem
	Guy Dallaire
	D. Chris Daniels
	Renata Maria Dart
	Ian Darwin
	Carl E. Davidson
	David Day
	Will Day
	Frederic Delanoy
	Mike Depot
	Steve Dibbell
	Hugh Dickins
	David DiGiacomo
	Casper Dik
	John DiMarco
	Don Draper
	Bryan Drewery
	Michel Dubois
	Eric Dumazet
	Dick Dunbar
	Marc Duponcheel
	Jan Dvorak
	Calle Dybedahl
	John Dzubera
	Jeff Earickson
	Greg Earle
	Bernd Eckenfels
	Niklas Edmundsson
	Philip Edwards
	Robert Ehrlich
	Mark W. Eichin
	Doug Eldred
	Scott Ellentuch
	Tom Endo
	Grant Erickson
	Craig Everhart
	Chris Evert
	Bob Farmer
	Sami Farin
	Mike Feldman
	Quentin Fennessy
	Ian Fitchet
	Toralf Foerster
	Bob Foertsch
	Pierre-Yves Fontaniere
	Ralph Forsythe
	Jason Fortezzo
	Mike Fraser
	Curt Freeland
	Terry Friedrichsen
	Mike Frysinger
	Harvey Garner
	Carson Gaspar
	Stuart D. Gathman
	Brian L. Gentry
	Dave Gilbert
	Steve Ginsberg
	Bjarni Ingi Gislason
	Edwin Groothuis
	Jin Guojun
	Kurt Gollhardt
	Roman Gollent
	Steve Gonczi
	Bill Goodridge
	Julian Gordon
	Marcin Gozdalik
	Henry Grebler
	Richard Green
	Chaskiel Grundman
	Armin Gruner
	David Gutierrez
	Mateusz Guzik
	Robert Hall
	Garner Halloran
	Adam Hammer
	Charles Hannum
	Vlad Harchev
	Craig Harmer
	Michael Haro
	Peter Harvey
	Steinar Haug
	Jia He
	Sheldon Hearn
	John Heasley
	Wolfgang Hecht
	Janet Hempstead
	Michael Hennecke
	Randolph J. Herber
	Allen Hewes
	Andrew Hill
	Kurt Hillig
	Steven Hinkle
	Paul Hite
	Billy Ho
	Michael Hocke
	Brett Hogden
	Gaylord Holder
	Kjetil Torgrim Homme
	Pekka Honkanen
	Jeffrey C. Honig
	Heidi Hornstein
	Michael A. Hovan III
	Barbara Howe
	J. Nelson Howell
	Jeff Howie
	Louis Huemiller
	John Hughes
	Gerrit Huizenga
	Peter Ilieve
	Mayer Ilovitz
	Gregory A. Ivanov
	John Jackson
	Kurt Jaeger
	Edward Jajko
	Marian Jancar
	Paul Jarc
	Jakub Jelinek
	Robert Jelinek
	Bruce Jerrick
	Carl Johnson
	Dion Johnson
	Jeff Johnson
	Douglas B. Jones
	LaMont Jones
	Peter Jordan
	Arne H. Juul
	Pasi Kaara
	Frank Kaefer
	Keith Kalet
	Claus Kalle
	Henri Karrenbeld
	Amir Katz
	Henry Katz
	Kawaljeet Kaur
	Doug Kehn
	Kris Kennaway
	Terry Kennedy
	Shane Kenney
	Andrew Kephart
	Robert Kiessling
	Joshua Kinard
	Don Kirouac
	Steve Kirsch
	Philip Kizer
	Thomas Klausner
	Roger Klorese
	Peter Klosky
	Przemek Klosowski
	Angelos D. Keromytis
	Radko Keves
	Valdis Kletnieks
	Chris Kordish
	Alek O. Komarnitsky
	Joseph Kowalski
	Christian Krackowizer
	Paul Kranenburg
	Troyan Krastev
	Brad Krebs
	Alex Kreis
	Johannes Kroeger
	Vincent Kujala
	Ken Laing
	Shirley Lam
	Erwin Lansing
	Victoria H. Lau
	Markus Lautenbacher
	Steve Lacey
	Marc Aurele La France
	Chad R. Larson
	Steve Laubscher
	Andrei V. Lavreniyuk
	Loc Le
	Tin Le
	Diane Lebel
	Francis Le Bourse
	Kyungjoon Lee
	Marty Leisner
	Maciej Lesniewski
	Stuart Levy
	Ben Lewis
	Michael Lewis
	Angel Li
	Ambrose Li
	Wendy Lin
	Carl E. Lindberg
	Onno van der Linden
	Johan Lindquist
	James Lingard
	Jason Lingohr
	Robert Lipe
	Gabor Liptak
	Friedel Loinger
	Michael Long
	Pete Lord
	Steve Logue
	Bela Lubkin
	Pav Lucistnik
	Horst Luehrsen
	Andreas Luik
	Timothy J. Luoma
	Michael Mackenzie
	Lawrence MacIntyre
	Jerome Marchand
	Benson Margulies
	Claude Marinier
	Chris Markle
	Roy Marples
        Ed Maste
	Eberhard Mater
	James Mathiesen
	Tom Matthews
	Fletcher Mattox
	David Mazieres
	Brian McAllister
	Scott McClung
	Dale McCluskey
	Terry McCoy
	Sean McDermott
	Duncan McEwan
	Dwight McKay
	William McVey
	Eric McWhorter
	Marjo F. Mercado
	Dan Mercer
	Bill Melvin
	Andrew Merril
	Richard van Meurs
	Jim Mewes
	Ivan Melnikov
	Conrad Meyer
	Hendrik Meyer
	Gary Millen
	Timothy Miller
	Davin Milun
	Yuliy Minchev
	Jim Mintha
	Mike Miscevic
	Arkadiusz Miskiewicz
	Janardhan Molumuri
	Nasser Momtaheni
	Laurent Montaron
	Doug Moore
	Phillip Moore
	Dmitry Morozovsky
	John Paul Morrison
	John Gardiner Myers
	Jeffrey Mogul
	Dave Morrison
	Pat Myrto
	Toshiya Nakamura
	Filippo Natali
	Allan Nathanson
	Chance Neale
	Dan Nelson
	Vladislav Nespor
	Bjorn S. Nilsson
	Anders Nordby
	Joseph J. Nuspl Jr.
	David O'Brien
	Alexandre Oliva
	Craig B. Olofson
	Dave Olson
	Rainer Orth
	Sergey A. Osokin
	Keith Parks
	Will Partain
	Vasco Pedro
	Mark Peek
	Ezra Peisach
	Bill Pemberton
	Lee Penn
	Gildas Perrot
	Jesse Perry
	Nathan Peterson
	Dominique Petitpierre
	Hung Pham
	Ray Phillips
	Francois Pinard
	Gary Plewa
	Alex Podlecki
	Lutz Poetschulat,
	John Polstra
	Scott Presnell
	Mark Price
	Philippe-Andre Prindeville
	Kristof Provost
	David Putz
	Tom Qin
	Jan Rybar
	Kurtis Rader
	Peter Radig
	Jean-Pierre Radley
	Tim Ramsey
	Dewan Rashid
	Richard J. Rauenzahn
	Louis Rayman
	Brian Redman
	Eric S. Raymond
	Erwin Reyns
	Aaron Rhodes
	Jim Reid
	Jean-Luc Richier
	Clint Roberts
	Ingimar Robertson
	Sylvain Robitaille
	Larry Rogers
	Malgorzata Roos
	Larry Rosenman
	Stephan Rossi
	Kevin Ruderman
	Wolfgang Rupprecht
	Pavol Rusnak
	Eygene Ryabinkin
	Conrad J. Sabatier
	Klaus Saggerer
	Chris Schanzle
	Igor Schein
	Horst Scheuermann
	Peter Schiffer
	Michael Schmitz
	Larry Schwimmer
	Cy Schubert
	Hendrik G. Seliger
	Igor V. Semenyuk
	Jonathan Sergent
	Frank Sanders
	Berkley Shands
	Gregory Neil Shapiro
	Eyal Shaynis
	Michael Shields
	Wesley Shields
	Philip Shin
	Anthony Shortland
	Dave Sill
	John Silva
	Chuck Silvers
	Gerry Singleton
	Leonard Sitongia
	Kevin Smallwood
	Gleb Smirnoff
	Curt Smith
	Ben Smithurst
	Douglas R. Smith
	Kevin Smith
	Chang Song
	Josh Soref
	John Speno
	Kenneth Stailey
	Piet Starreveld
	David Steiner
	Charles Stephens
	Marc Stephenson
	Chip Stettler
	Dave Stevens
	Jeff Stewart
	Diana Stockdale
	Andreas Stolcke
	Jeff Stoner
	Kristyna Streitova
	Sushila Subramanian
	Jan Ole Suhr
	Mike Sullivan
	Patrick D. Sullivan
	Peter Svensson
	Chris Sylvain
	Miklos Szeredi
	Paul Szabo
	Dale Talcott
	Jon A. Tankersley
	Jan Tax
	Samuel Thibault
	Andy Thomas
	Matthew Thurmaier
	Chris Timmons
	Andrzej Tobola
	R. Lindsay Todd
	Zdenko Tomasic
	Michael Townsend
	Linus Torvalds
	Mike Tracy
	Jeff Trawick
	Dan Trinkle
	Erik Trulsson
	Lars Tunkrans
	Lenny Turetsky
	Kevin Vajk
	Peter Valchev
	John R. Vanderpool
	Peter Van Epp
	Peter C. Vernam
	Peter Vines
	Bob Ward
	Jules van Weerden
	Tom Weaver
	Fernando A.B. Whitaker
	Tom Whitty
	Carson Wilson
	David J. Wilson
	Frank Winkler
	Marc Winkler
	Mark Vasoll
	Holger VanKoll
	Robert Vernon
	Joep Vesseur
	Larry Virden
	Jos Vos
	Jun Biao Wang
	Christopher J Warweg
	Bill Watson
	Florian M. Weps
	Joel White
	Paul Wickman
	Martin Wilke
	Eric Williams
	Steve Williams
	Steve Wilson
	Erich Wimmer
	Wally Winzer, Jr.
	Patrick Wolfe
	Stephen Woods
	James Woodward
	Scott Worley
	Jan Wortelboer
	Joshua Wright
	Sailu Yallapragada
	Masatake YAMATO
	Donna Yobs
	Ron Young
	Warren Young
	Blair Zajac
	Karel Zak
	Donald Zoch
	Malcom Zung
	Waldemar Zurowski
	@eranik (github account)
	@jolmg  (github account)
	yasu@utahime.org (email)
	jamie@catflap.org (email)
	@hardikpnsp (github account)
	Martin D Kealey
	Henry Peteet
	@zhrf2020
	@JustAnotherArchivist
	@po5857
	@albert-github
	Tobias Geerinckx-Rice
	Andres Salomon
	Nicholas Bamber
	Grisha Levit
	@10ne1 (github account)
	@a1346054
	Damjan Jovanovic
	Fabrice Fontaine
	Danny Fowler
	Benny "BenBE" Baumann
	Robert Geislinger (Alienmaster)
	Subhaditya Nath
	Sergei Trofimovich (@trofi)
	Danilo Spinella (@danyspin97)
	Jiajie Chen (@jiegec)
	Jacob Chapman (@chapmanjacobd)
	Teng Hu (@Hunter1016)
	Li Zeming (@likunyur)
	Sam James (@thesamesam)
	Warner Losh (@bsdimp)
	Andrew Athan (@aathan)
	Florian Weimer (@fweimer-rh) and
	Andreas Schwab (@andreas-schwab)

If I have omitted a contributor's name, the fault is wholly mine,
and I apologize for the error.

Vic Abell <abe@purdue.edu>
March 27, 2018

Masatake YAMATO <yamato@redhat.com> (since revision 4.92.1)
October 4, 2020

==> lsof-4.99.0.tar.gz: lsof-4.99.0/docs/credits.md <==
## Credits

I owe an enormous debt to the users of lsof who have contributed
to its steady growth.  The size of the list of people who have
helped me, while it has grown too large to include in the lsof man
page any more, is a testimonial to their generosity.

First I acknowledge a debt to the work of Dan Bernstein, Michael
`Ford` Ditto, Tom Dunigan, Alexander Dupuy, Vik Lall, Ray Moody,
C. Spencer, Michael Spitzer and those who wrote Berkeley's fstat
program, all contributors to lsof's predecessors.

I thank Doug McKenzie for his HP-UX proctor program and Rich Kulawiec
for pointing it out.

Finally I thank all the following people who have used lsof, pointed
out its flaws, described its shortcomings, offered suggestions for
improving it, supplied code for it, gave me technical advice, and
provided test systems where I was able to do development work.

	Szilveszter Adam
	David Addison
	Elias Halldor Agustsson
	Per Allansson
	Jim Ankenbrandt
	Richard Allen
	Thomas Anders
	Ric Anderson
	Stuart Anderson
	Dimitry Andric
	Michael Antlitz
	Cato Auestad
	Marc Auslander
	Tigran Aivazian
	Jos Backus
	David Bacon
	Alexis Ballier
	Scott Ballew
	Ade Barkah
	Alon Bar-Lev
	Brett Bartick
	Anthony Baxter
	John Beacom
	Bruce Beare
	M. Jay Beck
	Marek Behun
	Bill Behr
	Michael Beirne
	Marc Bejarano
	Andrew Bell
	Steve Bellenot
	Robert Benites
	Dmitry Berezin
	Ulrich Bernhard
	Peter J. Bertoncini
	Dave Bianchi
	Mark Bixby
	Allan Black
	Jan Blunck
	Achim Bohnet
	Steve Bonds
	Mark Bonsack
	Volker Borchert
	Bill Bormann
	Ermin Borovac
	Heddy Boubaker
	Pieter Bowman
	Michael Bracewell
	H. Merijn Brand
	Danny Braniss
	Thomas Braunbeck
	Kieran Broadfoot
	Dean Brock
	Hal Brooks
	Andrew Brown
	Jim Brown
	Michael Bryan
	Matthew Burt
	Robert Byrnes
	Pierfrancesco Caci
	Bill Campbell
	David Capshaw
	John Caruso
	Jon Champlin
	Kris Chandrasekhar
	Stephane Chazelas
	Andrey Chernov
	Albert Chin-A-Young
	Bernt Christandl
	Marc Christensen
	Hans Petter Christiansen
	Tom Christiansen
	Yves Christophe
	Richard Chycoski
	A. Channing Clark
	Jorn Clausen
	Axel Clauberg
	John Clear
	David Clissold
	Richard Coley
	John Colgrave
	David Comay
	Lionel Cons
	Bob Cook
	Patrick Connor
	Carl Cook
	Jim Cooper
	Roger Cornelius
	Doug Crabill
	Eric Cronin
	Kim Culhan
	Dave Curry
	Robert Dahlem
	Guy Dallaire
	D. Chris Daniels
	Renata Maria Dart
	Ian Darwin
	Carl E. Davidson
	David Day
	Will Day
	Frederic Delanoy
	Mike Depot
	Steve Dibbell
	Hugh Dickins
	David DiGiacomo
	Casper Dik
	John DiMarco
	Don Draper
	Bryan Drewery
	Michel Dubois
	Eric Dumazet
	Dick Dunbar
	Marc Duponcheel
	Jan Dvorak
	Calle Dybedahl
	John Dzubera
	Jeff Earickson
	Greg Earle
	Bernd Eckenfels
	Niklas Edmundsson
	Philip Edwards
	Robert Ehrlich
	Mark W. Eichin
	Doug Eldred
	Scott Ellentuch
	Tom Endo
	Grant Erickson
	Craig Everhart
	Chris Evert
	Bob Farmer
	Sami Farin
	Mike Feldman
	Quentin Fennessy
	Ian Fitchet
	Toralf Foerster
	Bob Foertsch
	Pierre-Yves Fontaniere
	Ralph Forsythe
	Jason Fortezzo
	Mike Fraser
	Curt Freeland
	Terry Friedrichsen
	Mike Frysinger
	Harvey Garner
	Carson Gaspar
	Stuart D. Gathman
	Brian L. Gentry
	Dave Gilbert
	Steve Ginsberg
	Bjarni Ingi Gislason
	Edwin Groothuis
	Jin Guojun
	Kurt Gollhardt
	Roman Gollent
	Steve Gonczi
	Bill Goodridge
	Julian Gordon
	Marcin Gozdalik
	Henry Grebler
	Richard Green
	Chaskiel Grundman
	Armin Gruner
	David Gutierrez
	Mateusz Guzik
	Robert Hall
	Garner Halloran
	Adam Hammer
	Charles Hannum
	Vlad Harchev
	Craig Harmer
	Michael Haro
	Peter Harvey
	Steinar Haug
	Jia He
	Sheldon Hearn
	John Heasley
	Wolfgang Hecht
	Janet Hempstead
	Michael Hennecke
	Randolph J. Herber
	Allen Hewes
	Andrew Hill
	Kurt Hillig
	Steven Hinkle
	Paul Hite
	Billy Ho
	Michael Hocke
	Brett Hogden
	Gaylord Holder
	Kjetil Torgrim Homme
	Pekka Honkanen
	Jeffrey C. Honig
	Heidi Hornstein
	Michael A. Hovan III
	Barbara Howe
	J. Nelson Howell
	Jeff Howie
	Louis Huemiller
	John Hughes
	Gerrit Huizenga
	Peter Ilieve
	Mayer Ilovitz
	Gregory A. Ivanov
	John Jackson
	Kurt Jaeger
	Edward Jajko
	Marian Jancar
	Paul Jarc
	Jakub Jelinek
	Robert Jelinek
	Bruce Jerrick
	Carl Johnson
	Dion Johnson
	Jeff Johnson
	Douglas B. Jones
	LaMont Jones
	Peter Jordan
	Arne H. Juul
	Pasi Kaara
	Frank Kaefer
	Keith Kalet
	Claus Kalle
	Henri Karrenbeld
	Amir Katz
	Henry Katz
	Kawaljeet Kaur
	Doug Kehn
	Kris Kennaway
	Terry Kennedy
	Shane Kenney
	Andrew Kephart
	Robert Kiessling
	Joshua Kinard
	Don Kirouac
	Steve Kirsch
	Philip Kizer
	Thomas Klausner
	Roger Klorese
	Peter Klosky
	Przemek Klosowski
	Angelos D. Keromytis
	Radko Keves
	Valdis Kletnieks
	Chris Kordish
	Alek O. Komarnitsky
	Joseph Kowalski
	Christian Krackowizer
	Paul Kranenburg
	Troyan Krastev
	Brad Krebs
	Alex Kreis
	Johannes Kroeger
	Vincent Kujala
	Ken Laing
	Shirley Lam
	Erwin Lansing
	Victoria H. Lau
	Markus Lautenbacher
	Steve Lacey
	Marc Aurele La France
	Chad R. Larson
	Steve Laubscher
	Andrei V. Lavreniyuk
	Loc Le
	Tin Le
	Diane Lebel
	Francis Le Bourse
	Kyungjoon Lee
	Marty Leisner
	Maciej Lesniewski
	Stuart Levy
	Ben Lewis
	Michael Lewis
	Angel Li
	Ambrose Li
	Wendy Lin
	Carl E. Lindberg
	Onno van der Linden
	Johan Lindquist
	James Lingard
	Jason Lingohr
	Robert Lipe
	Gabor Liptak
	Friedel Loinger
	Michael Long
	Pete Lord
	Steve Logue
	Bela Lubkin
	Pav Lucistnik
	Horst Luehrsen
	Andreas Luik
	Timothy J. Luoma
	Michael Mackenzie
	Lawrence MacIntyre
	Jerome Marchand
	Benson Margulies
	Claude Marinier
	Chris Markle
	Roy Marples
        Ed Maste
	Eberhard Mater
	James Mathiesen
	Tom Matthews
	Fletcher Mattox
	David Mazieres
	Brian McAllister
	Scott McClung
	Dale McCluskey
	Terry McCoy
	Sean McDermott
	Duncan McEwan
	Dwight McKay
	William McVey
	Eric McWhorter
	Marjo F. Mercado
	Dan Mercer
	Bill Melvin
	Andrew Merril
	Richard van Meurs
	Jim Mewes
	Ivan Melnikov
	Conrad Meyer
	Hendrik Meyer
	Gary Millen
	Timothy Miller
	Davin Milun
	Yuliy Minchev
	Jim Mintha
	Mike Miscevic
	Arkadiusz Miskiewicz
	Janardhan Molumuri
	Nasser Momtaheni
	Laurent Montaron
	Doug Moore
	Phillip Moore
	Dmitry Morozovsky
	John Paul Morrison
	John Gardiner Myers
	Jeffrey Mogul
	Dave Morrison
	Pat Myrto
	Toshiya Nakamura
	Filippo Natali
	Allan Nathanson
	Chance Neale
	Dan Nelson
	Vladislav Nespor
	Bjorn S. Nilsson
	Anders Nordby
	Joseph J. Nuspl Jr.
	David O'Brien
	Alexandre Oliva
	Craig B. Olofson
	Dave Olson
	Rainer Orth
	Sergey A. Osokin
	Keith Parks
	Will Partain
	Vasco Pedro
	Mark Peek
	Ezra Peisach
	Bill Pemberton
	Lee Penn
	Gildas Perrot
	Jesse Perry
	Nathan Peterson
	Dominique Petitpierre
	Hung Pham
	Ray Phillips
	Francois Pinard
	Gary Plewa
	Alex Podlecki
	Lutz Poetschulat,
	John Polstra
	Scott Presnell
	Mark Price
	Philippe-Andre Prindeville
	Kristof Provost
	David Putz
	Tom Qin
	Jan Rybar
	Kurtis Rader
	Peter Radig
	Jean-Pierre Radley
	Tim Ramsey
	Dewan Rashid
	Richard J. Rauenzahn
	Louis Rayman
	Brian Redman
	Eric S. Raymond
	Erwin Reyns
	Aaron Rhodes
	Jim Reid
	Jean-Luc Richier
	Clint Roberts
	Ingimar Robertson
	Sylvain Robitaille
	Larry Rogers
	Malgorzata Roos
	Larry Rosenman
	Stephan Rossi
	Kevin Ruderman
	Wolfgang Rupprecht
	Pavol Rusnak
	Eygene Ryabinkin
	Conrad J. Sabatier
	Klaus Saggerer
	Chris Schanzle
	Igor Schein
	Horst Scheuermann
	Peter Schiffer
	Michael Schmitz
	Larry Schwimmer
	Cy Schubert
	Hendrik G. Seliger
	Igor V. Semenyuk
	Jonathan Sergent
	Frank Sanders
	Berkley Shands
	Gregory Neil Shapiro
	Eyal Shaynis
	Michael Shields
	Wesley Shields
	Philip Shin
	Anthony Shortland
	Dave Sill
	John Silva
	Chuck Silvers
	Gerry Singleton
	Leonard Sitongia
	Kevin Smallwood
	Gleb Smirnoff
	Curt Smith
	Ben Smithurst
	Douglas R. Smith
	Kevin Smith
	Chang Song
	Josh Soref
	John Speno
	Kenneth Stailey
	Piet Starreveld
	David Steiner
	Charles Stephens
	Marc Stephenson
	Chip Stettler
	Dave Stevens
	Jeff Stewart
	Diana Stockdale
	Andreas Stolcke
	Jeff Stoner
	Kristyna Streitova
	Sushila Subramanian
	Jan Ole Suhr
	Mike Sullivan
	Patrick D. Sullivan
	Peter Svensson
	Chris Sylvain
	Miklos Szeredi
	Paul Szabo
	Dale Talcott
	Jon A. Tankersley
	Jan Tax
	Samuel Thibault
	Andy Thomas
	Matthew Thurmaier
	Chris Timmons
	Andrzej Tobola
	R. Lindsay Todd
	Zdenko Tomasic
	Michael Townsend
	Linus Torvalds
	Mike Tracy
	Jeff Trawick
	Dan Trinkle
	Erik Trulsson
	Lars Tunkrans
	Lenny Turetsky
	Kevin Vajk
	Peter Valchev
	John R. Vanderpool
	Peter Van Epp
	Peter C. Vernam
	Peter Vines
	Bob Ward
	Jules van Weerden
	Tom Weaver
	Fernando A.B. Whitaker
	Tom Whitty
	Carson Wilson
	David J. Wilson
	Frank Winkler
	Marc Winkler
	Mark Vasoll
	Holger VanKoll
	Robert Vernon
	Joep Vesseur
	Larry Virden
	Jos Vos
	Jun Biao Wang
	Christopher J Warweg
	Bill Watson
	Florian M. Weps
	Joel White
	Paul Wickman
	Martin Wilke
	Eric Williams
	Steve Williams
	Steve Wilson
	Erich Wimmer
	Wally Winzer, Jr.
	Patrick Wolfe
	Stephen Woods
	James Woodward
	Scott Worley
	Jan Wortelboer
	Joshua Wright
	Sailu Yallapragada
	Masatake YAMATO
	Donna Yobs
	Ron Young
	Warren Young
	Blair Zajac
	Karel Zak
	Donald Zoch
	Malcom Zung
	Waldemar Zurowski
	@eranik (github account)
	@jolmg  (github account)
	yasu@utahime.org (email)
	jamie@catflap.org (email)
	@hardikpnsp (github account)
	Martin D Kealey
	Henry Peteet
	@zhrf2020
	@JustAnotherArchivist
	@po5857
	@albert-github
	Tobias Geerinckx-Rice
	Andres Salomon
	Nicholas Bamber
	Grisha Levit
	@10ne1 (github account)
	@a1346054
	Damjan Jovanovic
	Fabrice Fontaine
	Danny Fowler
	Benny "BenBE" Baumann
	Robert Geislinger (Alienmaster)
	Subhaditya Nath
	Sergei Trofimovich (@trofi)
	Danilo Spinella (@danyspin97)
	Jiajie Chen (@jiegec)
	Jacob Chapman (@chapmanjacobd)
	Teng Hu (@Hunter1016)
	Li Zeming (@likunyur)
	Sam James (@thesamesam)
	Warner Losh (@bsdimp)
	Andrew Athan (@aathan)
	Florian Weimer (@fweimer-rh)
	Andreas Schwab (@andreas-schwab)
	@oldmanhere
	@mjoerg
	Subhaditya Nath (@subnut)
	Linjie Li (@uniontech-lilinjie)
	Clement Martin (@clementmartin) and
	Kalin KOZHUHAROV (@thinrope)

If I have omitted a contributor's name, the fault is wholly mine,
and I apologize for the error.

Vic Abell <abe@purdue.edu>
March 27, 2018

Masatake YAMATO <yamato@redhat.com> (since revision 4.92.1)
October 4, 2020
